==> quantulum-0.1.6.tar.gz: quantulum-0.1.6/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

import sys
try:
    reload(sys).setdefaultencoding('UTF-8')
except:
    pass

try:
    from setuptools import setup, find_packages
except ImportError:
    print('Please install or upgrade setuptools or pip to continue')
    sys.exit(1)

import codecs
import quantulum

setup(
    name='quantulum',
    packages=find_packages(),
    data_files=[('resources', ['resources/clf.pickle',
                               'resources/entities.json',
                               'resources/units.json',
                               'resources/wiki.json',
                               'resources/train.json',
                               'resources/tests.json'])],
    description='Extract quantities from unstructured text.',
    long_description=open('README.rst').read(),
    download_url='https://github.com/marcolagi/quantulum/tarball/0.1',
    version=quantulum.__version__,
    url=quantulum.__url__,
    author=quantulum.__author__,
    author_email=quantulum.__author_email__,
    license=quantulum.__license__,
    keywords=['information extraction', 'quantities', 'units', 'measurements',
              'nlp', 'natural language processing', 'text mining',
              'text processing'],
    install_requires=[
          'inflect', 'stemming'
      ],
    classifiers=[
          'Intended Audience :: Developers',
          'Intended Audience :: Science/Research',
          'Operating System :: MacOS :: MacOS X',
          'Operating System :: Microsoft :: Windows',
          'Operating System :: POSIX',
          'License :: OSI Approved :: MIT License',
          'Programming Language :: Python',
          'Programming Language :: Python :: 2.7',
          'Development Status :: 3 - Alpha',
          'Natural Language :: English',
          'Topic :: Software Development :: Libraries :: Python Modules',
          'Topic :: Text Processing :: Linguistic',
          'Topic :: Scientific/Engineering'
    ]
)

==> quantulum-0.1.7.tar.gz: quantulum-0.1.7/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

import sys
try:
    reload(sys).setdefaultencoding('UTF-8')
except:
    pass

try:
    from setuptools import setup, find_packages
except ImportError:
    print('Please install or upgrade setuptools or pip to continue')
    sys.exit(1)

import codecs
import quantulum

setup(
    name='quantulum',
    packages=find_packages(),
    data_files=[('resources', ['quantulum/resources/clf.pickle',
                               'quantulum/resources/entities.json',
                               'quantulum/resources/units.json',
                               'quantulum/resources/wiki.json',
                               'quantulum/resources/train.json',
                               'quantulum/resources/tests.json'])],
    description='Extract quantities from unstructured text.',
    long_description=open('README.rst').read(),
    download_url='https://github.com/marcolagi/quantulum/tarball/0.1',
    version=quantulum.__version__,
    url=quantulum.__url__,
    author=quantulum.__author__,
    author_email=quantulum.__author_email__,
    license=quantulum.__license__,
    keywords=['information extraction', 'quantities', 'units', 'measurements',
              'nlp', 'natural language processing', 'text mining',
              'text processing'],
    install_requires=[
          'inflect', 'stemming'
      ],
    classifiers=[
          'Intended Audience :: Developers',
          'Intended Audience :: Science/Research',
          'Operating System :: MacOS :: MacOS X',
          'Operating System :: Microsoft :: Windows',
          'Operating System :: POSIX',
          'License :: OSI Approved :: MIT License',
          'Programming Language :: Python',
          'Programming Language :: Python :: 2.7',
          'Development Status :: 3 - Alpha',
          'Natural Language :: English',
          'Topic :: Software Development :: Libraries :: Python Modules',
          'Topic :: Text Processing :: Linguistic',
          'Topic :: Scientific/Engineering'
    ]
)
